@@ -4,14 +4,13 @@ This module defines the ServerConf configuration model and provides
 a function to run a Uvicorn server with the specified settings.
 """
 
-from __future__ import annotations
-
 from typing import Annotated
 
 import uvicorn
-from engrate_sdk import log
 from pydantic import BaseModel, Field
 
+from engrate_sdk.utils import log
+
 logger = log.get_logger(__name__)
 
 
@@ -39,14 +38,21 @@ class ServerConf(BaseModel):
 #### Actions ####
 
 
-def run(conf: ServerConf, app_ref: str):
-    """Runs the server."""
-    logger.info(f"Starting server on {conf.host}:{conf.port}")
-    uvicorn.run(
-        app_ref,
-        host=conf.host,
-        port=conf.port,
-        log_level="debug" if conf.debug else "info",
-        reload=conf.autoreload,
-        log_config=None,
-    )
+class HttpServer:
+    """HTTP server runner for the Engrate SDK.
+
+    This class provides a method to run the server with the specified configuration.
+    """
+
+    @staticmethod
+    def run(conf: ServerConf, app_ref: str):
+        """Runs the server."""
+        logger.info(f"Starting server on {conf.host}:{conf.port}")
+        uvicorn.run(  # type: ignore
+            app_ref,
+            host=conf.host,
+            port=conf.port,
+            log_level="debug" if conf.debug else "info",
+            reload=conf.autoreload,
+            log_config=None,
+        )
